<div class="row">
  <div class="col-sm-12">
    <div class="mt-3 mb-0 w-100 border-custom rounded bg-lightgrey" data-toggle="collapse" data-target="#{{ this.args.name }}">
      <div class="d-table w-100 py-2 px-2 py-md-0 px-md-0">
        <div class="d-table-cell align-middle card-icon px-3 py-3">
          {% if this.args.img %}
            <img src="{{ url_for('static', filename=this.args.img) }}" class="w-100 px-1 py-1 rounded bg-white border-grey">
          {% endif %}
        </div>
        <div class="d-table-cell align-middle">
          <div class="very-small regular pb-2 pr-5">{{ this.args.title }}</div>
          <div class="tiny light text-muted">{{ this.args.subtitle }}</div>
        </div>
      </div>
    </div>
    <div id="{{ this.args.name }}" class="border-grey mx-2 border-top-0 rounded-bottom tiny collapse show">
      <div class="pt-3">
        {% for _field in _fields %}
          {{ _field.render() }}
        {% endfor %}
      </div>
    </div>
  </div>
</div>